@@ -5,7 +5,8 @@ import importlib
 import os
 import sys
 
-from utils import underscore_to_camelcase
+from utils.text_conversion import underscore_to_camelcase
+from utils.terminal import print_status
 
 
 def all_facts():
@@ -43,17 +44,52 @@ def get_class(module_name, dimension=False):
     return my_class
 
 
+def print_summary(errors):
+    """Print out a summary of the errors which happened during run_command."""
+    print_status("Summary", format='reverse', space=True, timestamp=False,
+                 indent=False)
+    if len(errors) == 0:
+        print_status("Everything went fine!", format='green', timestamp=False,
+                     indent=False)
+    else:
+        print_status("{0} commands not executed: {1}".format(
+                len(errors),
+                ", ".join(errors.keys())
+                ),
+            timestamp=False,
+            indent=False
+            )
+        template = "- {0}: {1}"
+        items = [template.format(key, value) for key, value in errors.items()]
+        print_status(
+            "\n".join(items),
+            timestamp=False,
+            indent=False
+            )
+
+
 def run_command(facts, command):
     """
     Run command for each fact in facts.
 
     """
     from connection import DB
+    errors = {}
+    
     with DB(settings.pylytics_db) as database_connection:
         for fact in facts:
-            sys.stdout.write("Running %s %s\n" % (fact, command))
-            MyFact = get_class(fact)(connection=database_connection)
-            getattr(MyFact, command)()
+            print_status("Running {0} {1}".format(fact, command),
+                         format='blue', indent=False, space=True,
+                         timestamp=False)
+            try:
+                MyFact = get_class(fact)(connection=database_connection)
+                getattr(MyFact, command)()
+            except Exception as e:
+                print_status("Running {0} {1} failed!".format(fact, command),
+                             format='red')
+                errors['.'.join([fact, command])] = e
+    
+    print_summary(errors)
 
 
 def load_settings(settings_path):
@@ -94,7 +130,8 @@ def main():
     command = args['command'][0]
     
     if 'all' in facts:
-        sys.stdout.write('Running all fact scripts:\n')
+        print_status('Running all fact scripts:', indent=False,
+                     timestamp=False, format='reverse', space=True)
         facts = all_facts()
     
     # Import settings:
